@@ -1,8 +1,8 @@
 # flake8: noqa
 # This is so ruff doesn't remove * imports
 
-from .list_memory import *
+from .local_memory import *
 
 __all__ = [
-    "ListMemory",
+    "LocalMemory",
 ]
